@@ -1,6 +1,6 @@
 /* repint_subrs.h -- library-local prototypes
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: repint_subrs.h,v 1.49 2001/09/14 14:37:33 jsh Exp $
+   $Id: repint_subrs.h,v 1.51 2002/10/07 07:42:10 jsh Exp $
 
    This file is part of Jade.
 
@@ -59,6 +59,17 @@ extern rep_xsubr Slambda;
 extern repv Qload_filename;
 extern repv Fcall_with_exception_handler (repv, repv);
 extern void rep_lispcmds_init(void);
+extern repv Flist_star (int argc, repv *argv);
+extern repv Fnconc_ (int argc, repv *argv);
+extern repv Fappend (int argc, repv *argv);
+extern repv Fvector (int argc, repv *argv);
+extern repv Fconcat (int, repv *);
+extern repv Fnum_eq (int, repv *);
+extern repv Fnum_noteq (int, repv *);
+extern repv Fgtthan (int, repv *);
+extern repv Fgethan (int, repv *);
+extern repv Fltthan (int, repv *);
+extern repv Flethan (int, repv *);
 
 /* from lispmach.c */
 extern repv Qbytecode_error;
@@ -89,6 +100,16 @@ extern void rep_misc_init(void);
 extern repv rep_parse_number (char *buf, u_int len, u_int radix,
 			      int sign, u_int type);
 extern void rep_numbers_init (void);
+extern repv Fplus(int, repv *);
+extern repv Fminus(int, repv *);
+extern repv Fproduct(int, repv *);
+extern repv Fdivide(int, repv *);
+extern repv Flogior(int, repv *);
+extern repv Flogxor(int, repv *);
+extern repv Flogand(int, repv *);
+extern repv Fmax(int, repv *);
+extern repv Fmin(int, repv *);
+extern repv Fgcd (int, repv *);
 
 /* from origin.c */
 extern rep_bool rep_record_origins;
